==> hls_player-1.0.6.tar.gz: android/src/main/java/cl/axg/hls_player/EPG.java <==
package cl.axg.hls_player;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
class EPG{
    private String titulo;
    private long horaInicio;
    private long horaFin;
    private int duracion;


    public EPG( String titulo, String horaInicio,  String horaFin, String duracion){
        this.titulo = titulo;
        this.horaInicio = Long.parseLong(horaInicio);
        this.horaFin =  Long.parseLong(horaFin);
        this.duracion = Integer.parseInt(duracion);
    }

    public String getTitulo(){
        return  this.titulo ;
    }

    public long getHoraFin(){
        return  this.horaFin ;
    }
    public String getHoraFinFormato(){
        return new java.text.SimpleDateFormat("HH:mm").format(new java.util.Date(this.horaFin * 1000));
    }
    public long getHoraInicio(){
        return  this.horaInicio ;
    }
    public String getHoraInicioFormato(){
        return new java.text.SimpleDateFormat("HH:mm").format(new java.util.Date(this.horaInicio * 1000));
    }

    public int getDuracion(){
        return this.duracion;
    }

    public  int getPercentageLeft() throws ParseException {

        long now = System.currentTimeMillis();
        Date fecha_now = new Date(now );

        Date fecha_inicio = new Date(Long.parseLong(this.horaInicio + "000") );
        String fecha_inicio_formato =  new java.text.SimpleDateFormat(" H:m:s").format(fecha_inicio);


        Date fecha_fin =new Date(Long.parseLong(this.horaFin + "000") );
        String fecha_fin_formato =  new java.text.SimpleDateFormat(" H:m:s").format(fecha_fin);

        Date fecha_actual =new Date(System.currentTimeMillis()  );


        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd H:m:s");

        Date fechaInicial=dateFormat.parse(new java.text.SimpleDateFormat("yyyy-MM-dd").format(fecha_actual)+fecha_inicio_formato);
        Date fechaFinal=dateFormat.parse(  new java.text.SimpleDateFormat("yyyy-MM-dd").format(fecha_actual)+fecha_fin_formato);
        Date fecha_now1=dateFormat.parse(  dateFormat.format(fecha_actual));


        //in milliseconds
        long diff = fechaFinal.getTime() - fecha_now1.getTime();

        long diffSeconds = diff / 1000 % 60;
        long diffMinutes = diff / (60 * 1000) % 60;
        long diffHours = diff / (60 * 60 * 1000) % 24;
        long diffDays = diff / (24 * 60 * 60 * 1000);

        System.out.print(diffDays + " days, ");
        System.out.print(diffHours + " hours, ");
        System.out.print(diffMinutes + " minutes, ");
        System.out.print(diffSeconds + " seconds.");

        long now1 = fecha_now1.getTime();
        long s = fechaInicial.getTime();
        long e = fechaFinal.getTime();
        if (s >= e || now1 >= e) {
            return 0;
        }
        if (now1 <= s) {
            return 100;
        }
        return 100 - (int) ((e - now1) * 100 / (e - s));
    }

}

==> hls_player-1.1.6.tar.gz: android/src/main/java/cl/axg/hls_player/EPG.java <==
package cl.axg.hls_player;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
class EPG{
    private String titulo;
    private long horaInicio;
    private long horaFin;
    private int duracion;


    public EPG( String titulo, String horaInicio,  String horaFin, String duracion){
        this.titulo = titulo;
        this.horaInicio = Long.parseLong(horaInicio);
        this.horaFin =  Long.parseLong(horaFin);
        this.duracion = Integer.parseInt(duracion);
    }

    public String getTitulo(){
        return  this.titulo ;
    }

    public long getHoraFin(){
        return  this.horaFin ;
    }
    public String getHoraFinFormato(){
        return new java.text.SimpleDateFormat("HH:mm").format(new java.util.Date(Long.parseLong(this.horaFin+ "000") ));
    }
    public long getHoraInicio(){
        return  this.horaInicio ;
    }
    public String getHoraInicioFormato(){
         return new java.text.SimpleDateFormat("HH:mm").format(new java.util.Date(Long.parseLong(this.horaInicio+ "000")) );
    }

    public int getDuracion(){
        return this.duracion;
    }

    public  int getPercentageLeft() throws ParseException {

        long now = System.currentTimeMillis();
        Date fecha_now = new Date(now );

        Date fecha_inicio = new Date(Long.parseLong(this.horaInicio + "000") );
        String fecha_inicio_formato =  new java.text.SimpleDateFormat(" H:m:s").format(fecha_inicio);


        Date fecha_fin =new Date(Long.parseLong(this.horaFin + "000") );
        String fecha_fin_formato =  new java.text.SimpleDateFormat(" H:m:s").format(fecha_fin);

        Date fecha_actual =new Date(System.currentTimeMillis()  );


        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd H:m:s");

        Date fechaInicial=dateFormat.parse(new java.text.SimpleDateFormat("yyyy-MM-dd").format(fecha_actual)+fecha_inicio_formato);
        Date fechaFinal=dateFormat.parse(  new java.text.SimpleDateFormat("yyyy-MM-dd").format(fecha_actual)+fecha_fin_formato);
        Date fecha_now1=dateFormat.parse(  dateFormat.format(fecha_actual));


        //in milliseconds
        long diff = fechaFinal.getTime() - fecha_now1.getTime();

        long diffSeconds = diff / 1000 % 60;
        long diffMinutes = diff / (60 * 1000) % 60;
        long diffHours = diff / (60 * 60 * 1000) % 24;
        long diffDays = diff / (24 * 60 * 60 * 1000);

        System.out.print(diffDays + " days, ");
        System.out.print(diffHours + " hours, ");
        System.out.print(diffMinutes + " minutes, ");
        System.out.print(diffSeconds + " seconds.");

        long now1 = fecha_now1.getTime();
        long s = fechaInicial.getTime();
        long e = fechaFinal.getTime();
        if (s >= e || now1 >= e) {
            return 0;
        }
        if (now1 <= s) {
            return 100;
        }
        return 100 - (int) ((e - now1) * 100 / (e - s));
    }

}
